==> haskell-singleton-bool-0.1.8-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-7ikkAPvQzaLB3gwIp59x8n
key:                  singleton-bool-0.1.8-7ikkAPvQzaLB3gwIp59x8n
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  2c36a7392eb81a889b306b283a82f622
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-7ikkAPvQzaLB3gwIp59x8n
depends:
    base-4.17.2.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    some-1.0.6-JkdHyfs6syy2LeJ2tPR7fo

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singleton-bool-0.1.8-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singleton-bool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 singleton-bool
version:              0.1.8
visibility:           public
id:                   singleton-bool-0.1.8-HNTwsUSLQUoJc2X6gFoNSF
key:                  singleton-bool-0.1.8-HNTwsUSLQUoJc2X6gFoNSF
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/singleton-bool#readme
synopsis:             Type level booleans
description:
    Type level booleans.

    @singletons@ package provides similar functionality,
    but it has tight dependency constraints.

category:             Dependent Types
abi:                  019b8d9818fc9f9315ea26d990f6b78e
exposed:              True
exposed-modules:      Data.Singletons.Bool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/singleton-bool-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-singleton-bool
hs-libraries:         HSsingleton-bool-0.1.8-HNTwsUSLQUoJc2X6gFoNSF
depends:
    base-4.17.2.1 boring-0.2.2-HI9VvaC9JR142cnMpyID0P
    dec-0.0.6-C66T8uIzry9Gen6Yxn0qxQ deepseq-1.4.8.0
    some-1.0.6-IiRblKvQPLw6GFNXPDbNXz

haddock-interfaces:
    /usr/share/doc/haskell-singleton-bool/html/singleton-bool.haddock

haddock-html:         /usr/share/doc/haskell-singleton-bool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
